/**
 * Copyright (C) 2003 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.objectweb.util.monolog.component;

import org.objectweb.util.monolog.api.LoggerFactory;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.LevelFactory;
import org.objectweb.util.monolog.api.Level;
import org.objectweb.util.monolog.api.HandlerFactory;
import org.objectweb.util.monolog.api.Handler;
import org.objectweb.util.monolog.api.MonologFactory;
import org.objectweb.util.monolog.Monolog;

import java.util.Properties;

/**
 * Is a simple fractal component encapsualiting a MonologFactory.
 * 
 * @author S.Chassande-Barrioz
 */
public class MonologComponent
		implements MonologFactory, MonologAttributes {

	private static MonologFactory singleton = Monolog.getDefaultMonologFactory();

	public static LoggerFactory getLoggerFactory() {
		return singleton;
	}

	public static LevelFactory getLevelFactory() {
		return singleton;
	}

	public static HandlerFactory getHandlerFactory() {
		return singleton;
	}


	private MonologFactory factory;
	private String fileName;

	public MonologComponent() {
		factory = Monolog.getDefaultMonologFactory();
	}

	// IMPLEMENTATION OF THE LoggerFactory INTERFACE //
	//-----------------------------------------------//

	public String getPropertiesFileName() {
		return fileName;
	}

	public void setPropertiesFileName(String propfn) {
		if (fileName != null && fileName.equals(propfn))
			return;
		fileName = propfn;
		if (propfn != null) {
			factory = Monolog.getMonologFactory(propfn);
			if (singleton != Monolog.getDefaultMonologFactory()) {
				singleton = factory;
			}
		}
	}

	// IMPLEMENTATION OF THE LoggerFactory INTERFACE //
	//-----------------------------------------------//

	public Logger getLogger(String key) {
		return factory.getLogger(key);
	}

	public Logger getLogger(String key, String resourceBundleName) {
		return factory.getLogger(key, resourceBundleName);
	}

	public String getResourceBundleName() {
		return factory.getResourceBundleName();
	}

	public void setResourceBundleName(String resourceBundleName) {
		factory.setResourceBundleName(resourceBundleName);
	}

	public Logger[] getLoggers() {
		return factory.getLoggers();
	}


	// IMPLEMENTATION OF THE LoggerFactory INTERFACE //
	//-----------------------------------------------//

	public Level defineLevel(String name, int value) {
		return factory.defineLevel(name, value);
	}

	public Level defineLevel(String name, String value) {
		return factory.defineLevel(name, value);
	}

	public Level getLevel(String name) {
		return factory.getLevel(name);
	}

	public Level getLevel(int value) {
		return factory.getLevel(value);
	}

	public Level[] getLevels() {
		return factory.getLevels();
	}

	public void removeLevel(String name) {
		factory.removeLevel(name);
	}


	// IMPLEMENTATION OF THE HandlerFactory INTERFACE //
	//------------------------------------------------//

	public Handler createHandler(String hn, byte handlertype) {
		return factory.createHandler(hn, handlertype);
	}

	public Handler[] getHandlers() {
		return factory.getHandlers();
	}

	public Handler getHandler(String handlername) {
		return factory.getHandler(handlername);
	}

	public Handler removeHandler(String handlername) {
		return factory.removeHandler(handlername);
	}

	// IMPLEMENTATION OF THE MonologFactory INTERFACE //
	//------------------------------------------------//

	public void configure(Properties prop) throws Exception {
		factory.configure(prop);
	}
}
