/**
 * Copyright (C) 2004 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.objectweb.util.monolog;

import junit.framework.TestCase;
import org.objectweb.util.monolog.api.MonologFactory;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class TestSimple extends TestCase {

	static MonologFactory mf = null;

	public TestSimple(String s) {
		super(s);
	}

	protected void setUp() throws Exception {
		if (mf == null) {
			synchronized(TestSimple.class) {
				if (mf == null) {
					mf = Monolog.getMonologFactory("monolog.properties");
				}
			}
		}
	}

	public void test1() {
		logAllLevel(mf.getLogger("org.objectweb.util.monolog.test.fatal"));
		logAllLevel(mf.getLogger("org.objectweb.util.monolog.test.error"));
		logAllLevel(mf.getLogger("org.objectweb.util.monolog.test.warn"));
		logAllLevel(mf.getLogger("org.objectweb.util.monolog.test.info"));
		logAllLevel(mf.getLogger("org.objectweb.util.monolog.test.debug"));
	}

	private void logAllLevel(Logger logger) {
		logger.log(BasicLevel.FATAL, "-----------------"
		    + "\n\tlogger.name: " + logger.getName()
		    + "\n\tlogger.class: " + logger.getClass().getName()
		    + "\n\tlevel=" + logger.getCurrentLevel().getName());
		logger.log(BasicLevel.FATAL, "message FATAL ...");
		logger.log(BasicLevel.ERROR, "message ERROR ...");
		logger.log(BasicLevel.WARN,  "message WARN ...");
		logger.log(BasicLevel.INFO,  "message INFO ...");
		logger.log(BasicLevel.DEBUG, "message DEBUG ...");
	}

}
